==> alfresco-repository-25.1.2.5-sources.jar: org/alfresco/repo/rawevents/types/OnContentUpdatePolicyEvent.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2018 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail.  Otherwise, the software is
 * provided under the following open source license terms:
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.rawevents.types;

/**
 * Event that is raised once per node when any of the content properties on the
 * node are changed; the specific properties are irrelevant. This is primarily
 * useful to determine when a new file is introduced into the system.
 */
public class OnContentUpdatePolicyEvent extends EventImpl
{
    private String nodeRef;
    private boolean newContent;

    public String getNodeRef()
    {
        return nodeRef;
    }

    public void setNodeRef(String nodeRef)
    {
        this.nodeRef = nodeRef;
    }

    public boolean isNewContent()
    {
        return newContent;
    }

    public void setNewContent(boolean newContent)
    {
        this.newContent = newContent;
    }
}

==> alfresco-repository-25.3.1.2-sources.jar: org/alfresco/repo/rawevents/types/OnContentUpdatePolicyEvent.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2018 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail.  Otherwise, the software is
 * provided under the following open source license terms:
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.rawevents.types;

/**
 * Event that is raised once per node when any of the content properties on the node are changed; the specific properties are irrelevant. This is primarily useful to determine when a new file is introduced into the system.
 */
public class OnContentUpdatePolicyEvent extends EventImpl
{
    private String nodeRef;
    private boolean newContent;

    public String getNodeRef()
    {
        return nodeRef;
    }

    public void setNodeRef(String nodeRef)
    {
        this.nodeRef = nodeRef;
    }

    public boolean isNewContent()
    {
        return newContent;
    }

    public void setNewContent(boolean newContent)
    {
        this.newContent = newContent;
    }
}
